<?php $TRANSLATIONS = array(
"Sunday" => "Dominica",
"Monday" => "Lunedi",
"Tuesday" => "Martedi",
"Wednesday" => "Mercuridi",
"Thursday" => "Jovedi",
"Friday" => "Venerdi",
"Saturday" => "Sabbato",
"January" => "januario",
"February" => "Februario",
"March" => "Martio",
"April" => "April",
"May" => "Mai",
"June" => "Junio",
"July" => "Julio",
"August" => "Augusto",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Decembre",
"Settings" => "Configurationes",
"Cancel" => "Cancellar",
"Share" => "Compartir",
"Password" => "Contrasigno",
"ownCloud password reset" => "Reinitialisation del contrasigno de ownCLoud",
"Username" => "Nomine de usator",
"Request reset" => "Requestar reinitialisation",
"Your password was reset" => "Tu contrasigno esseva reinitialisate",
"To login page" => "al pagina de initio de session",
"New password" => "Nove contrasigno",
"Reset password" => "Reinitialisar contrasigno",
"Personal" => "Personal",
"Users" => "Usatores",
"Apps" => "Applicationes",
"Admin" => "Administration",
"Help" => "Adjuta",
"Access forbidden" => "Accesso prohibite",
"Cloud not found" => "Nube non trovate",
"Edit categories" => "Modificar categorias",
"Add" => "Adder",
"Create an <strong>admin account</strong>" => "Crear un <strong>conto de administration</strong>",
"Advanced" => "Avantiate",
"Data folder" => "Dossier de datos",
"Configure the database" => "Configurar le base de datos",
"will be used" => "essera usate",
"Database user" => "Usator de base de datos",
"Database password" => "Contrasigno de base de datos",
"Database name" => "Nomine de base de datos",
"Database host" => "Hospite de base de datos",
"web services under your control" => "servicios web sub tu controlo",
"Log out" => "Clauder le session",
"Lost your password?" => "Tu perdeva le contrasigno?",
"remember" => "memora",
"Log in" => "Aperir session",
"prev" => "prev",
"next" => "prox"
);
